@@ -3,16 +3,13 @@ import React from "react";
 import { Logo, LogoIcon } from "./StyledComponents";
 
 const LogoComponent = () => {
-  return (
-    <Box>
-        <Logo>
-            <LogoIcon
-                alt=""
-                src="/favicon.ico"
-            />
-        </Logo>
-    </Box>
-  );
+    return (
+        <Box>
+            <Logo>
+                <LogoIcon alt="" src="/favicon.ico" />
+            </Logo>
+        </Box>
+    );
 };
 
-export default LogoComponent;
\ No newline at end of file
+export default LogoComponent;
