@@ -73,19 +73,19 @@ class PythonProcess {
         let _this = this;
         this.executor.on("message", function (stdout) {
             try {
-                console.log("On message: ", _this.clientMessage);
-                let replyMessage = JSON.parse(_this.clientMessage);
-                console.log("stdout: forward output to client", replyMessage);
+                // console.log("On message: ", _this.clientMessage);
+                // let replyMessage = JSON.parse(_this.clientMessage);
                 // replyMessage["content"] = stdout;
                 // _this.send2client(replyMessage);
+                console.log("stdout: ", stdout);
             } catch (error) {
                 console.log(error.stack);
             }
         });
 
         this.executor.on("stderr", function (stderr) {
-            let replyMessage = JSON.parse(_this.clientMessage);
-            console.log("stderr: forward output to client", replyMessage);
+            // let replyMessage = JSON.parse(_this.clientMessage);
+            // console.log("stderr: forward output to client", replyMessage);
             // replyMessage['content'] = stderr;
             // replyMessage['type'] = 'str';
             // _this.send2client(replyMessage);
@@ -177,7 +177,7 @@ try {
         const command_output_zmq = new zmq.Pull();
 
         const p2n_host = config.p2n_comm.host;
-        const p2n_port = config.p2n_comm.p2n_port;
+        const p2n_port = config.p2n_comm.port;
         await command_output_zmq.bind(`${p2n_host}:${p2n_port}`);
 
         // notification_zmq.bind(`${p2n_host}:${p2n_notif_port}`);
